#[repr(i32)]pub enum ResponseType {
Json = 0,
Html = 1,
}Variants
Json = 0
JSON error responses (default, backwards compatible)
Html = 1
HTML error pages (for user-facing web routes)
Implementations
Sourceimpl ResponseType
impl ResponseType
Sourceimpl ResponseType
impl ResponseType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.