pub enum Value {
BytesValue(Bytes),
Uint64Value(u64),
Uint32Value(u32),
BoolValue(bool),
StringValue(String),
}Variants
Implementations
Sourceimpl Value
impl Value
Sourcepub fn merge(
field: &mut Option<Value>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Value>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.