pub struct HealthResponse {
pub instance_id: Bytes,
pub status: i32,
pub version: String,
pub uptime_ms: i64,
pub message: String,
}Expand description
Services respond to health checks over syn-rpc
Fields
instance_id: Bytesstatus: i32version: Stringuptime_ms: i64message: StringOptional status message (e.g., reason for degradation)
Implementations
Sourceimpl HealthResponse
impl HealthResponse
Sourcepub fn status(&self) -> HealthStatus
pub fn status(&self) -> HealthStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: HealthStatus)
pub fn set_status(&mut self, value: HealthStatus)
Sets status to the provided enum value.