pub struct StateTransferFailed {
pub transfer_id: Bytes,
pub reason: i32,
pub details: String,
}Fields
transfer_id: Bytesreason: i32details: StringImplementations
Sourceimpl StateTransferFailed
impl StateTransferFailed
Sourcepub fn reason(&self) -> FailureReason
pub fn reason(&self) -> FailureReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: FailureReason)
pub fn set_reason(&mut self, value: FailureReason)
Sets reason to the provided enum value.